@@ -295,7 +295,6 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
  # Need to give each build job it's own yarn cache, as the yarn cache is not safe for concurrent builds.
  # For more info: https://github.com/yarnpkg/yarn/issues/683#issuecomment-346038525
     yarn_cache=os.getenv('PWD','') + '@tmp/.yarn_cache'
-    local('mkdir -p .yarn_cache')
     local('yarn config set cache-folder %s' % yarn_cache)
 
     with lcd(installPath):
@@ -306,7 +305,7 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
  
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
-            local('Hyarn build %s %s' % (options, ngApp))
+            local('yarn build %s %s' % (options, ngApp))
             local('cp {package.json,yarn.lock,knexfile.js} dist/')
             local('cp -R migrations/ dist/migrations')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
